
/**
 *
 */
export default async function() {
  const localeConfig = await import(LOCALE_CONFIG)

  const {native, fallbacks} = localeConfig
  const preferences = getLocalePreferrences()

  return {
    fallbacks,
    native,
    preferences,
  }
}

/**
 *
 */
function getLocalePreferrences() {

  // Get an array of user language preferrences.
  // https://developer.mozilla.org/en-US/docs/Web/API/NavigatorLanguage/languages
  const langArr = window.navigator.languages || [window.navigator.language || window.navigator.userLanguage]

  const langMapArr = langArr
    .map(raw => {
      const parts = raw.replace('-', '_').split('_')
      const [language] = parts
      const country = parts.length > 1 ? parts[1].toUpperCase() : false
      const locale = country ? `${language}_${country}` : false

      return {
        language,
        country,
        locale,
      }
    })

  const locales = langMapArr
    .map(choice => choice.locale)
    .filter(locale => locale)

  const languages = langMapArr
    .map(choice => choice.language)

  return {
    languages,
    locales,
  }
}